@@ -1,4 +1,4 @@
-if [ ! -f /etc/multitail.conf ]
+if [ ! -e /etc/multitail.conf ]
 then
     /usr/bin/mkdir -p /etc
     /usr/bin/cp /etc/defaults/etc/multitail.conf /etc/multitail.conf
